@@ -93,7 +93,7 @@ covmat_internal <- function (traces, start, thin, expand = 2.38, ...) {
   nms <- colnames(traces)
   keep <- seq.int(from=as.integer(start),to=dd[1],by=as.integer(thin))
   if (length(keep) < 100)
-    pWarn("covmat","only ",length(keep),
+    pWarn(who="covmat","only ",length(keep),
       ngettext(length(keep)," point is"," points are"),
       " being used to estimate covariance matrix.")
   if (length(dd)==2L) {
