@@ -22,7 +22,7 @@
 ##' @param rw.sd specification of the magnitude of the random-walk perturbations that will be applied to some or all model parameters.
 ##' Parameters that are to be estimated should have positive perturbations specified here.
 ##' The specification is given using the \code{\link{rw_sd}} function, which creates a list of unevaluated expressions.
-##' The latter are evaluated in a context where the model time variable is defined (as \code{time}).
+##' The latter are evaluated in a context where vector of observation times is visible (as \sQuote{\code{time}}).
 ##' The expression \code{ivp(s)} can be used in this context as shorthand for \preformatted{ifelse(time==time[1],s,0).}
 ##' Likewise, \code{ivp(s,lag)} is equivalent to \preformatted{ifelse(time==time[lag],s,0).}
 ##' See below for some examples.
@@ -55,17 +55,26 @@
 ##'
 ##' @section Specifying the perturbations:
 ##' The \code{rw_sd} function simply returns a list containing its arguments as unevaluated expressions.
-##' These are then evaluated in a context containing the model \code{time} variable.
+##' These are then evaluated in a context in which the vector of observation times is defined (as \sQuote{\code{time}}).
 ##' This allows for easy specification of the structure of the perturbations that are to be applied.
 ##' For example,
 ##' \preformatted{
-##'     rw_sd(a=0.05, b=ifelse(time==time[1],0.2,0),
-##'           c=ivp(0.2), d=ifelse(time==time[13],0.2,0),
-##'           e=ivp(0.2,lag=13), f=ifelse(time<23,0.02,0))
+##'     rw_sd(
+##'       a=0.05,
+##'       b=ifelse(time==time[1], 0.2, 0),
+##'       c=ivp(0.2),
+##'       d=ifelse(time==time[13], 0.2, 0),
+##'       e=ivp(0.2, lag=13),
+##'       f=ifelse(time<23, 0.02, 0),
+##'       g=ifelse(time>=23 & time<50, 0.02, 0),
+##'       h=ivp(0.1,lags=3:8)
+##'     )
 ##' }
-##' results in perturbations of parameter \code{a} with s.d. 0.05 at every time step, while parameters \code{b} and \code{c} both get perturbations of s.d. 0.2 only just before the first observation.
-##' Parameters \code{d} and \code{e}, by contrast, get perturbations of s.d.  0.2 only just before the thirteenth observation.
-##' Finally, parameter \code{f} gets a random perturbation of size 0.02 before every observation falling before \eqn{t=23}.
+##' results in random perturbations of parameter \code{a} with s.d. 0.05 at every time step, while parameters \code{b} and \code{c} both get perturbations of s.d. 0.2 only before the first observation (i.e., at the zero-time).
+##' Parameters \code{d} and \code{e}, by contrast, get perturbations of s.d. 0.2 only before the thirteenth observation.
+##' Parameter \code{f} gets a random perturbation of size 0.02 before every observation falling before \eqn{t=23},
+##' while \code{g} gets perturbed before all observations that fall in the interval \eqn{23\le{t}<{50}}{23<=t<50}.
+##' Finally, the magnitude of the perturbation of parameter \code{h} is applied before the third through eighth observations.
 ##'
 ##' On the \eqn{m}-th IF2 iteration, prior to time-point \eqn{n}, the \eqn{d}-th parameter is given a random increment normally distributed with mean \eqn{0} and standard deviation \eqn{c_{m,n} \sigma_{d,n}}{c[m,n] sigma[d,n]}, where \eqn{c} is the cooling schedule and \eqn{\sigma}{sigma} is specified using \code{rw_sd}, as described above.
 ##' Let \eqn{N} be the length of the time series and \eqn{\alpha=}{alpha=}\code{cooling.fraction.50}.
@@ -125,16 +134,21 @@ setMethod(
 setMethod(
   "mif2",
   signature=signature(data="data.frame"),
-  definition = function (data,
-    Nmif = 1, rw.sd,
+  definition = function (
+    data,
+    ...,
+    Nmif = 1,
+    rw.sd,
     cooling.type = c("geometric", "hyperbolic"), cooling.fraction.50,
     Np,
     params, rinit, rprocess, dmeasure, partrans,
-    ..., verbose = getOption("verbose", FALSE)) {
+    verbose = getOption("verbose", FALSE)
+  ) {
 
     tryCatch(
       mif2_internal(
         data,
+        ...,
         Nmif=Nmif,
         rw.sd=rw.sd,
         cooling.type=match.arg(cooling.type),
@@ -145,7 +159,6 @@ setMethod(
         rprocess=rprocess,
         dmeasure=dmeasure,
         partrans=partrans,
-        ...,
         verbose=verbose
       ),
       error = function (e) pStop(who="mif2",conditionMessage(e))
@@ -159,20 +172,26 @@ setMethod(
 setMethod(
   "mif2",
   signature=signature(data="pomp"),
-  definition = function (data,
-    Nmif = 1, rw.sd,
-    cooling.type = c("geometric", "hyperbolic"), cooling.fraction.50,
-    Np, ..., verbose = getOption("verbose", FALSE)) {
+  definition = function (
+    data,
+    ...,
+    Nmif = 1,
+    rw.sd,
+    cooling.type = c("geometric", "hyperbolic"),
+    cooling.fraction.50,
+    Np,
+    verbose = getOption("verbose", FALSE)
+  ) {
 
     tryCatch(
       mif2_internal(
         data,
+        ...,
         Nmif=Nmif,
         rw.sd=rw.sd,
         cooling.type=match.arg(cooling.type),
         cooling.fraction.50=cooling.fraction.50,
         Np=Np,
-        ...,
         verbose=verbose
       ),
       error = function (e) pStop(who="mif2",conditionMessage(e))
@@ -186,17 +205,20 @@ setMethod(
 setMethod(
   "mif2",
   signature=signature(data="pfilterd_pomp"),
-  definition = function (data,
+  definition = function (
+    data,
+    ...,
     Nmif = 1, Np,
-    ..., verbose = getOption("verbose", FALSE)) {
+    verbose = getOption("verbose", FALSE)
+  ) {
 
     if (missing(Np)) Np <- data@Np
 
     mif2(
       as(data,"pomp"),
+      ...,
       Nmif=Nmif,
       Np=Np,
-      ...,
       verbose=verbose
     )
   }
@@ -207,10 +229,15 @@ setMethod(
 setMethod(
   "mif2",
   signature=signature(data="mif2d_pomp"),
-  definition = function (data,
-    Nmif, rw.sd,
-    cooling.type, cooling.fraction.50,
-    ..., verbose = getOption("verbose", FALSE)) {
+  definition = function (
+    data,
+    ...,
+    Nmif,
+    rw.sd,
+    cooling.type,
+    cooling.fraction.50,
+    verbose = getOption("verbose", FALSE)
+  ) {
 
     if (missing(Nmif)) Nmif <- data@Nmif
     if (missing(rw.sd)) rw.sd <- data@rw.sd
@@ -219,11 +246,11 @@ setMethod(
 
     mif2(
       as(data,"pfilterd_pomp"),
+      ...,
       Nmif=Nmif,
       rw.sd=rw.sd,
       cooling.type=cooling.type,
       cooling.fraction.50=cooling.fraction.50,
-      ...,
       verbose=verbose
     )
 
@@ -236,14 +263,18 @@ setMethod(
 setMethod(
   "continue",
   signature=signature(object="mif2d_pomp"),
-  definition = function (object, Nmif = 1, ...) {
+  definition = function (
+    object,
+    ...,
+    Nmif = 1
+  ) {
 
     ndone <- object@Nmif
 
     obj <- mif2(
       object,
-      Nmif=Nmif,
       ...,
+      Nmif=Nmif,
       .ndone=ndone,
       .paramMatrix=object@paramMatrix
     )
@@ -260,10 +291,19 @@ setMethod(
   }
 )
 
-mif2_internal <- function (object, Nmif, rw.sd,
-  cooling.type, cooling.fraction.50, Np, ..., verbose,
-  .ndone = 0L, .indices = integer(0), .paramMatrix = NULL,
-  .gnsi = TRUE) {
+mif2_internal <- function (
+  object,
+  ...,
+  Nmif, rw.sd,
+  cooling.type,
+  cooling.fraction.50,
+  Np,
+  verbose,
+  .ndone = 0L,
+  .indices = integer(0),
+  .paramMatrix = NULL,
+  .gnsi = TRUE
+) {
 
   verbose <- as.logical(verbose)
 
@@ -396,8 +436,13 @@ mif2_cooling <- function (type, fraction, ntimes) {
   )
 }
 
-mif2_pfilter <- function (object, params, Np, mifiter, rw.sd, cooling.fn,
-  verbose, .indices = integer(0), .gnsi = TRUE) {
+mif2_pfilter <- function (
+  object,
+  params, Np, mifiter, rw.sd, cooling.fn,
+  verbose,
+  .indices = integer(0),
+  .gnsi = TRUE
+) {
 
   gnsi <- as.logical(.gnsi)
   verbose <- as.logical(verbose)
@@ -510,7 +555,7 @@ perturbn_kernel_sd <- function (rw.sd, time, paramnames) {
       sQuote("params"),": ",paste(lapply(unrec,sQuote),collapse=","),".")
   }
   ivp <- function (sd, lag = 1L) {
-    sd*(seq_along(time)==lag)
+    sd*(seq_along(time) %in% lag)
   }
   sds <- lapply(rw.sd,eval,envir=list(time=time,ivp=ivp),enclos=enclos)
   for (n in names(sds)) {
