@@ -68,6 +68,22 @@ SEXP D_Euler_Multinom (SEXP x, SEXP size, SEXP rate, SEXP deltat, SEXP log) {
   return f;
 }
 
+SEXP E_Euler_Multinom (SEXP size, SEXP rate, SEXP deltat) {
+  int ntrans = length(rate);
+  SEXP x;
+  if (length(size)>1)
+    warn("in 'eeulermultinom': only the first element of 'size' is meaningful");
+  if (length(deltat)>1)
+    warn("in 'eeulermultinom': only the first element of 'dt' is meaningful");
+  PROTECT(size = AS_NUMERIC(size));
+  PROTECT(rate = AS_NUMERIC(rate));
+  PROTECT(deltat = AS_NUMERIC(deltat));
+  PROTECT(x = duplicate(rate));
+  eeulermultinom(ntrans,*REAL(size),REAL(rate),*REAL(deltat),REAL(x));
+  UNPROTECT(4);
+  return x;
+}
+
 // This function draws a random increment of a gamma whitenoise process.
 // This will have expectation=dt and variance=(sigma^2*dt)
 // If dW = rgammawn(sigma,dt), then
