@@ -3,13 +3,15 @@
 #include <R.h>
 #include <Rmath.h>
 #include <Rdefines.h>
-#include "pomp_internal.h"
+#include "internal.h"
 
 // simple 2D Ornstein-Uhlenbeck process simulation
-static void sim_ou2 (double *x1, double *x2,
-  double alpha1, double alpha2, double alpha3, double alpha4,
-  double sigma1, double sigma2, double sigma3)
-{
+static void sim_ou2
+(
+ double *x1, double *x2,
+ double alpha1, double alpha2, double alpha3, double alpha4,
+ double sigma1, double sigma2, double sigma3
+ ) {
   double eps[2], xnew[2];
 
   eps[0] = rnorm(0,1);
@@ -24,10 +26,12 @@ static void sim_ou2 (double *x1, double *x2,
 
 // simple 2D Ornstein-Uhlenbeck process transition density
 // transition (x1,x2) -> (z1,z2) in 1 unit of time
-static double dens_ou2 (double x1, double x2, double z1, double z2,
-  double alpha1, double alpha2, double alpha3, double alpha4,
-  double sigma1, double sigma2, double sigma3, int give_log)
-{
+static double dens_ou2
+(
+ double x1, double x2, double z1, double z2,
+ double alpha1, double alpha2, double alpha3, double alpha4,
+ double sigma1, double sigma2, double sigma3, int give_log
+ ) {
   double eps[2], val;
 
   // compute residuals
@@ -64,39 +68,47 @@ static double dens_ou2 (double x1, double x2, double z1, double z2,
 #define V22   (f[vmatindex[3]])
 
 // onestep simulator for use in 'discrete.time.sim' plug-in
-void _ou2_step (double *x, const double *p,
-  const int *stateindex, const int *parindex, const int *covindex,
-  const double *covars, double t, double deltat)
-{
+void _ou2_step
+(
+ double *x, const double *p,
+ const int *stateindex, const int *parindex, const int *covindex,
+ const double *covars, double t, double deltat
+ ) {
   sim_ou2(&x[X1],&x[X2],ALPHA1,ALPHA2,ALPHA3,ALPHA4,SIGMA1,SIGMA2,SIGMA3);
 }
 
 // onestep transition probability density for use in 'onestep.dens' plug-in
 // transition from x to z as time goes from t1 to t2
-void _ou2_pdf (double *f,
-  double *x, double *z, double t1, double t2, const double *p,
-  const int *stateindex, const int *parindex, const int *covindex,
-  const double *covars)
-{
+void _ou2_pdf
+(
+ double *f,
+ double *x, double *z, double t1, double t2, const double *p,
+ const int *stateindex, const int *parindex, const int *covindex,
+ const double *covars
+ ) {
   if (t2-t1 != 1)
     err("ou2_pdf error: transitions must be consecutive");
   f[0] = dens_ou2(x[X1],x[X2],z[X1],z[X2],ALPHA1,ALPHA2,ALPHA3,ALPHA4,
-    SIGMA1,SIGMA2,SIGMA3,1);
+                  SIGMA1,SIGMA2,SIGMA3,1);
 }
 
-void _ou2_skel (double *f, double *x, double *p,
-  int *stateindex, int *parindex, int *covindex,
-  double *covars, double t)
-{
+void _ou2_skel
+(
+ double *f, double *x, double *p,
+ int *stateindex, int *parindex, int *covindex,
+ double *covars, double t
+ ) {
   f[X1] = ALPHA1*x[X1]+ALPHA3*x[X2];
   f[X2] = ALPHA2*x[X1]+ALPHA4*x[X2];
 }
 
 // bivariate normal measurement error density
-void _ou2_dmeasure (double *lik, double *y, double *x, double *p, int give_log,
-  int *obsindex, int *stateindex, int *parindex, int *covindex,
-  double *covar, double t)
-{
+void _ou2_dmeasure
+(
+ double *lik, double *y, double *x, double *p, int give_log,
+ int *obsindex, int *stateindex, int *parindex, int *covindex,
+ double *covar, double t
+ ) {
   double sd = fabs(TAU);
   double f = 0.0;
   f += (ISNA(Y1)) ? 0.0 : dnorm(Y1,x[X1],sd,1);
@@ -105,29 +117,35 @@ void _ou2_dmeasure (double *lik, double *y, double *x, double *p, int give_log,
 }
 
 // bivariate normal measurement error simulator
-void _ou2_rmeasure (double *y, double *x, double *p,
-  int *obsindex, int *stateindex, int *parindex, int *covindex,
-  double *covar, double t)
-{
+void _ou2_rmeasure
+(
+ double *y, double *x, double *p,
+ int *obsindex, int *stateindex, int *parindex, int *covindex,
+ double *covar, double t
+ ) {
   double sd = fabs(TAU);
   Y1 = rnorm(x[X1],sd);
   Y2 = rnorm(x[X2],sd);
 }
 
 // bivariate normal measurement error expectation
-void _ou2_emeasure (double *y, double *x, double *p,
-  int *obsindex, int *stateindex, int *parindex, int *covindex,
-  double *covar, double t)
-{
+void _ou2_emeasure
+(
+ double *y, double *x, double *p,
+ int *obsindex, int *stateindex, int *parindex, int *covindex,
+ double *covar, double t
+ ) {
   Y1 = x[X1];
   Y2 = x[X2];
 }
 
 // bivariate normal measurement variance
-void _ou2_vmeasure (double *f, double *x, double *p,
-  int *vmatindex, int *stateindex, int *parindex, int *covindex,
-  double *covar, double t)
-{
+void _ou2_vmeasure
+(
+ double *f, double *x, double *p,
+ int *vmatindex, int *stateindex, int *parindex, int *covindex,
+ double *covar, double t
+ ) {
   double sd = fabs(TAU);
   V11 = V22 = sd*sd;
   V12 = V21 = 0;
